==> serendipity_1.0.4.orig.tar.gz: serendipity/plugins/serendipity_plugin_remoterss/lang_pl.inc.php <==
<?php # $Id$

/**
 *  @version $Revision$
 *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_REMOTERSS_TITLE', 'Kanay RSS/OPML');
@define('PLUGIN_REMOTERSS_BLAHBLAH', 'Pokazuje wpisy z zewntrznych kanaw RSS/OPML (np. Blogroll)');
@define('PLUGIN_REMOTERSS_NUMBER', 'Ilo wpisw');
@define('PLUGIN_REMOTERSS_NUMBER_BLAHBLAH', 'Jak wiele wpisw ma by pokazywanych? (Standardowo: wszystkie wpisy danego feedu)');
@define('PLUGIN_REMOTERSS_SIDEBARTITLE', 'Tytu feedu');
@define('PLUGIN_REMOTERSS_SIDEBARTITLE_BLAHBLAH', 'Tytu feedu - bdzie pokazywany jako tytu na Panelu Bocznym');
@define('PLUGIN_REMOTERSS_RSSURI', 'RSS/OPML URI');
@define('PLUGIN_REMOTERSS_RSSURI_BLAHBLAH', 'URI kanau RSS/OPML, ktry chcesz pokaza');
@define('PLUGIN_REMOTERSS_NOURI', 'Nie wybrano adresu kanau RSS/OPML');
@define('PLUGIN_REMOTERSS_RSSTARGET', 'Docelowy adres linku RSS/OPML');
@define('PLUGIN_REMOTERSS_RSSTARGET_BLAHBLAH', 'Adres docelowy linkw podawanych przez kana RSS/OPML (Standardowo: _blank - linki bd otwierane w nowym oknie przegldarki)');
@define('PLUGIN_REMOTERSS_CACHETIME', 'Jak czsto pobiera dane?');
@define('PLUGIN_REMOTERSS_CACHETIME_BLAHBLAH', 'Zawarto feedu jest buforowana. Tu ustalasz jak czsto bufor ma by uaktualniany (w sekundach). (Standardowo: co 3 godziny - 10800 sekund)');
@define('PLUGIN_REMOTERSS_FEEDTYPE', 'Typ feedu');
@define('PLUGIN_REMOTERSS_FEEDTYPE_BLAHBLAH', 'Wybierz format podawanych przez kana danych');
@define('PLUGIN_REMOTERSS_BULLETIMG', 'Znak graficzny');
@define('PLUGIN_REMOTERSS_BULLETIMG_BLAHBLAH', 'Moesz tu poda link do obrazka, jaki bdzie wywietlany przed kadym pobranym wpisem.');
@define('PLUGIN_REMOTERSS_DISPLAYDATE', 'Wywietla dat?');
@define('PLUGIN_REMOTERSS_DISPLAYDATE_BLAHBLAH', 'Czy wywietla dat pod kad lini z wpisem?');

?>

==> serendipity_1.1.4.orig.tar.gz: serendipity/plugins/serendipity_plugin_remoterss/lang_pl.inc.php <==
<?php # $Id: lang_pl.inc.php 1549 2006-12-20 18:26:51Z garvinhicking $

/**
 *  @version $Revision: 1549 $
 *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_REMOTERSS_TITLE', 'Kanay RSS/OPML');
@define('PLUGIN_REMOTERSS_BLAHBLAH', 'Pokazuje wpisy z zewntrznych kanaw RSS/OPML (np. Blogroll)');
@define('PLUGIN_REMOTERSS_NUMBER', 'Ilo wpisw');
@define('PLUGIN_REMOTERSS_NUMBER_BLAHBLAH', 'Jak wiele wpisw ma by pokazywanych? (Standardowo: wszystkie wpisy danego feedu)');
@define('PLUGIN_REMOTERSS_SIDEBARTITLE', 'Tytu feedu');
@define('PLUGIN_REMOTERSS_SIDEBARTITLE_BLAHBLAH', 'Tytu feedu - bdzie pokazywany jako tytu na Panelu Bocznym');
@define('PLUGIN_REMOTERSS_RSSURI', 'RSS/OPML URI');
@define('PLUGIN_REMOTERSS_RSSURI_BLAHBLAH', 'URI kanau RSS/OPML, ktry chcesz pokaza');
@define('PLUGIN_REMOTERSS_NOURI', 'Nie wybrano adresu kanau RSS/OPML');
@define('PLUGIN_REMOTERSS_RSSTARGET', 'Docelowy adres linku RSS/OPML');
@define('PLUGIN_REMOTERSS_RSSTARGET_BLAHBLAH', 'Adres docelowy linkw podawanych przez kana RSS/OPML (Standardowo: _blank - linki bd otwierane w nowym oknie przegldarki)');
@define('PLUGIN_REMOTERSS_CACHETIME', 'Jak czsto pobiera dane?');
@define('PLUGIN_REMOTERSS_CACHETIME_BLAHBLAH', 'Zawarto feedu jest buforowana. Tu ustalasz jak czsto bufor ma by uaktualniany (w sekundach). (Standardowo: co 3 godziny - 10800 sekund)');
@define('PLUGIN_REMOTERSS_FEEDTYPE', 'Typ feedu');
@define('PLUGIN_REMOTERSS_FEEDTYPE_BLAHBLAH', 'Wybierz format podawanych przez kana danych');
@define('PLUGIN_REMOTERSS_BULLETIMG', 'Znak graficzny');
@define('PLUGIN_REMOTERSS_BULLETIMG_BLAHBLAH', 'Moesz tu poda link do obrazka, jaki bdzie wywietlany przed kadym pobranym wpisem.');
@define('PLUGIN_REMOTERSS_DISPLAYDATE', 'Wywietla dat?');
@define('PLUGIN_REMOTERSS_DISPLAYDATE_BLAHBLAH', 'Czy wywietla dat pod kad lini z wpisem?');

@define('PLUGIN_REMOTERSS_RSSLINK', 'Uy linku RSS?');
@define('PLUGIN_REMOTERSS_RSSLINK_DESC', 'Czy ma by wywietlony link podany w feedzie RSS?');
@define('PLUGIN_REMOTERSS_RSSFIELD', 'Wywietlanie elementw RSS');
@define('PLUGIN_REMOTERSS_RSSFIELD_DESC', 'Ktry z elementw feeda RSS ma by wywietlony? (np. "title", "content:encoded", "description", ...)');
@define('PLUGIN_REMOTERSS_RSSESCAPE', 'Wycz formatowanie HTML');
@define('PLUGIN_REMOTERSS_RSSESCAPE_DESC', 'Jeli ta opcja zostanie wczona, kod HTML w feedzie zostanie usunity. Jeli ta opcja zostanie wyczona, kod HTML w feedach bdzie interpretowany. To moe by potencjalne rdo problemw z bezpieczestwem bloga jeli feed nie pochodzi od Ciebie!');

?>
